@@ -636,7 +636,7 @@ int show(FILE* fd, char *name)
 {
 	long int cpurate;
 	long int cpuquota;
-	long int cpuperiod;
+	long int cpuperiod = 100000;
 	char buf[1024];
 
 //#ifdef __RHEL7__
